.. _getting_started:

Getting Started
===============

This getting started aims at introducing you to ``eodag`` and at getting you using
it efficiently as quickly as possible.

.. toctree::
   :maxdepth: 2

   overview
   install
   providers
   register
   product_types
   product_storage_status
   configure
   side_projects
